SystemOrganization addCategory: #'ToolBuilder-Kernel'!

Object subclass: #ToolBuilder
	instanceVariableNames: 'parent'
	classVariableNames: 'Default'
	poolDictionaries: ''
	category: 'ToolBuilder-Kernel'!

!ToolBuilder commentStamp: '<historical>' prior: 0!
I am a tool builder, that is an object which knows how to create concrete widgets from abstract specifications. Those specifications are used by tools which want to be able to function in diverse user interface paradigms, such as MVC, Morphic, Tweak, wxWidgets etc.

The following five specs must be supported by all implementations:
	* PluggableButton
	* PluggableList
	* PluggableText
	* PluggablePanel
	* PluggableWindow

The following specs are optional:
	* PluggableTree: If not supported, the tool builder must answer nil when asked for a pluggableTreeSpec. Substitution will require client support so clients must be aware that some tool builders may not support trees (MVC for example, or Seaside). See examples in FileListPlus or TestRunnerPlus.
	* PluggableMultiSelectionList: If multi-selection lists are not supported, tool builder will silently support regular single selection lists.
	* PluggableInputField: Intended as a HINT for the builder that this widget will be used as a single line input field. Unless explicitly supported it will be automatically substituted by PluggableText.
	* PluggableActionButton: Intended as a HINT for the builder that this widget will be used as push (action) button. Unless explicitly supported it will be automatically substituted by PluggableButton.
	* PluggableRadioButton: Intended as a HINT for the builder that this widget will be used as radio button. Unless explicitly supported it will be automatically substituted by PluggableButton.
	* PluggableCheckBox: Intended as a HINT for the builder that this widget will be used as check box. Unless explicitly supported it will be automatically substituted by PluggableButton.
!

!ToolBuilder class methodsFor: 'instance creation' stamp: 'KR 4/28/2006 21:05'!
build: aClass
	^self default build: aClass! !

!ToolBuilder class methodsFor: 'accessing' stamp: 'ar 2/11/2005 15:55'!
default
	"Answer the default tool builder"
	| builderClass |
	^Default ifNil:[
		"Note: The way the following is phrased ensures that you can always make 'more specific' builders merely by subclassing a tool builder and implementing a more specific way of reacting to #isActiveBuilder. For example, a BobsUIToolBuilder can subclass MorphicToolBuilder and (if enabled, say Preferences useBobsUITools) will be considered before the parent (generic MorphicToolBuilder)."
		builderClass := self allSubclasses 
			detect:[:any| any isActiveBuilder and:[
				any subclasses noneSatisfy:[:sub| sub isActiveBuilder]]] ifNone:[nil].
		builderClass ifNotNil:[builderClass new]]! !

!ToolBuilder class methodsFor: 'accessing' stamp: 'ar 2/11/2005 15:21'!
default: aToolBuilder
	"Set a new default tool builder"
	Default := aToolBuilder.! !

!ToolBuilder class methodsFor: 'accessing' stamp: 'ar 2/11/2005 15:23'!
isActiveBuilder
	"Answer whether I am the currently active builder"
	^false! !

!ToolBuilder class methodsFor: 'instance creation' stamp: 'ar 2/11/2005 18:15'!
open: aClass
	^self default open: aClass! !

!ToolBuilder class methodsFor: 'instance creation' stamp: 'ar 2/11/2005 18:15'!
open: aClass label: aString
	^self default open: aClass label: aString! !

!ToolBuilder methodsFor: 'building' stamp: 'ar 6/5/2005 12:35'!
build: anObject
	"Build the given object using this tool builder"
	^anObject buildWith: self! !

!ToolBuilder methodsFor: 'building' stamp: 'ar 6/5/2005 12:35'!
buildAll: aList in: newParent
	"Build the given set of widgets in the new parent"
	| prior |
	aList ifNil:[^self].
	prior := parent.
	parent := newParent.
	aList do:[:each| each buildWith: self].
	parent := prior.
! !

!ToolBuilder methodsFor: 'widgets optional' stamp: 'ar 2/12/2005 14:05'!
buildPluggableActionButton: spec
	^self buildPluggableButton: spec! !

!ToolBuilder methodsFor: 'widgets required' stamp: 'ar 2/9/2005 18:46'!
buildPluggableButton: aSpec
	^self subclassResponsibility! !

!ToolBuilder methodsFor: 'widgets optional' stamp: 'ar 2/12/2005 14:05'!
buildPluggableCheckBox: spec
	^self buildPluggableButton: spec! !

!ToolBuilder methodsFor: 'widgets optional' stamp: 'ar 2/12/2005 18:39'!
buildPluggableInputField: aSpec
	^self buildPluggableText: aSpec! !

!ToolBuilder methodsFor: 'widgets required' stamp: 'ar 2/9/2005 18:47'!
buildPluggableList: aSpec
	^self subclassResponsibility! !

!ToolBuilder methodsFor: 'widgets optional' stamp: 'ar 2/12/2005 14:06'!
buildPluggableMultiSelectionList: aSpec
	^self buildPluggableList: aSpec! !

!ToolBuilder methodsFor: 'widgets required' stamp: 'ar 6/5/2005 12:30'!
buildPluggablePanel: aSpec
	^self subclassResponsibility! !

!ToolBuilder methodsFor: 'widgets optional' stamp: 'ar 2/12/2005 14:05'!
buildPluggableRadioButton: spec
	^self buildPluggableButton: spec! !

!ToolBuilder methodsFor: 'widgets required' stamp: 'ar 2/9/2005 18:47'!
buildPluggableText: aSpec
	^self subclassResponsibility! !

!ToolBuilder methodsFor: 'widgets required' stamp: 'ar 2/12/2005 00:36'!
buildPluggableTree: aSpec
	^self subclassResponsibility! !

!ToolBuilder methodsFor: 'widgets required' stamp: 'ar 2/9/2005 18:47'!
buildPluggableWindow: aSpec
	^self subclassResponsibility! !

!ToolBuilder methodsFor: 'opening' stamp: 'ar 6/5/2005 12:37'!
close: aWidget
	"Close a previously opened widget"
	^self subclassResponsibility! !

!ToolBuilder methodsFor: 'opening' stamp: 'ar 6/5/2005 12:38'!
open: anObject
	"Build and open the object. Answer the widget opened."
	^self subclassResponsibility! !

!ToolBuilder methodsFor: 'opening' stamp: 'ar 6/5/2005 12:38'!
open: anObject label: aString
	"Build an open the object, labeling it appropriately.  Answer the widget opened."
	^self subclassResponsibility! !

!ToolBuilder methodsFor: 'accessing' stamp: 'ar 2/9/2005 18:54'!
parent
	^parent! !

!ToolBuilder methodsFor: 'accessing' stamp: 'ar 2/9/2005 18:54'!
parent: aWidget
	parent := aWidget! !

!ToolBuilder methodsFor: 'defaults' stamp: 'ar 2/12/2005 14:18'!
pluggableActionButtonSpec
	^PluggableActionButtonSpec! !

!ToolBuilder methodsFor: 'defaults' stamp: 'ar 2/10/2005 00:31'!
pluggableButtonSpec
	^PluggableButtonSpec! !

!ToolBuilder methodsFor: 'defaults' stamp: 'ar 2/12/2005 14:18'!
pluggableCheckBoxSpec
	^PluggableCheckBoxSpec! !

!ToolBuilder methodsFor: 'defaults' stamp: 'ar 2/11/2005 16:41'!
pluggableInputFieldSpec
	^PluggableInputFieldSpec! !

!ToolBuilder methodsFor: 'defaults' stamp: 'ar 2/10/2005 00:30'!
pluggableListSpec
	^PluggableListSpec! !

!ToolBuilder methodsFor: 'defaults' stamp: 'cwp 6/8/2005 23:24'!
pluggableMenuSpec
	^ PluggableMenuSpec! !

!ToolBuilder methodsFor: 'defaults' stamp: 'ar 2/12/2005 13:43'!
pluggableMultiSelectionListSpec
	^PluggableMultiSelectionListSpec! !

!ToolBuilder methodsFor: 'defaults' stamp: 'ar 2/10/2005 00:30'!
pluggablePanelSpec
	^PluggablePanelSpec! !

!ToolBuilder methodsFor: 'defaults' stamp: 'ar 2/12/2005 14:18'!
pluggableRadioButtonSpec
	^PluggableRadioButtonSpec! !

!ToolBuilder methodsFor: 'defaults' stamp: 'ar 2/10/2005 00:31'!
pluggableTextSpec
	^PluggableTextSpec! !

!ToolBuilder methodsFor: 'defaults' stamp: 'ar 2/12/2005 16:53'!
pluggableTreeSpec
	^PluggableTreeSpec! !

!ToolBuilder methodsFor: 'defaults' stamp: 'ar 2/10/2005 00:30'!
pluggableWindowSpec
	^PluggableWindowSpec! !

!ToolBuilder methodsFor: 'opening' stamp: 'ar 6/5/2005 12:39'!
runModal: aWidget
	"Run the (previously opened) widget modally, e.g., 
	do not return control to the sender before the user has responded."
	^self subclassResponsibility! !

!ToolBuilder methodsFor: 'accessing' stamp: 'ar 7/14/2005 22:23'!
widgetAt: widgetID
	"Answer the widget with the given ID"
	^self widgetAt: widgetID ifAbsent:[nil]! !

!ToolBuilder methodsFor: 'accessing' stamp: 'ar 7/14/2005 22:23'!
widgetAt: widgetID ifAbsent: aBlock
	"Answer the widget with the given ID"
	^aBlock value! !

Object subclass: #ToolBuilderSpec
	instanceVariableNames: 'name'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ToolBuilder-Kernel'!

!ToolBuilderSpec commentStamp: 'ar 2/11/2005 14:59' prior: 0!
I am an abstract widget specification. I can be rendered using many different UI frameworks.!

ToolBuilderSpec subclass: #PluggableMenuItemSpec
	instanceVariableNames: 'label action checked enabled separator subMenu help'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ToolBuilder-Kernel'!

!PluggableMenuItemSpec methodsFor: 'accessing' stamp: 'ar 2/28/2006 17:23'!
action
	"Answer the action associated with the receiver"
	^action! !

!PluggableMenuItemSpec methodsFor: 'accessing' stamp: 'ar 2/28/2006 17:23'!
action: aMessageSend
	"Answer the action associated with the receiver"
	action := aMessageSend! !

!PluggableMenuItemSpec methodsFor: 'building' stamp: 'ar 2/28/2006 17:23'!
buildWith: builder
	^ builder buildPluggableMenuItem: self! !

!PluggableMenuItemSpec methodsFor: 'accessing' stamp: 'ar 2/28/2006 17:28'!
checked
	"Answer whether the receiver is checked"
	^checked ifNil:[false]! !

!PluggableMenuItemSpec methodsFor: 'accessing' stamp: 'ar 2/28/2006 17:21'!
checked: aBool
	"Indicate whether the receiver is checked"
	checked := aBool.! !

!PluggableMenuItemSpec methodsFor: 'accessing' stamp: 'ar 2/28/2006 17:28'!
enabled
	"Answer whether the receiver is enabled"
	^enabled ifNil:[true]! !

!PluggableMenuItemSpec methodsFor: 'accessing' stamp: 'ar 2/28/2006 17:21'!
enabled: aBool
	"Indicate whether the receiver is enabled"
	enabled := aBool! !

!PluggableMenuItemSpec methodsFor: 'accessing' stamp: 'ar 2/28/2006 17:24'!
help
	"Answer the help text associated with the receiver"
	^help! !

!PluggableMenuItemSpec methodsFor: 'accessing' stamp: 'ar 2/28/2006 17:24'!
help: aString
	"Answer the help text associated with the receiver"
	help := aString.! !

!PluggableMenuItemSpec methodsFor: 'accessing' stamp: 'ar 2/28/2006 17:20'!
label
	"Answer the receiver's label"
	^label! !

!PluggableMenuItemSpec methodsFor: 'accessing' stamp: 'ar 2/28/2006 17:21'!
label: aString
	"Set the receiver's label"
	label := aString! !

!PluggableMenuItemSpec methodsFor: 'accessing' stamp: 'ar 2/28/2006 17:28'!
separator
	"Answer whether the receiver should be followed by a separator"
	^separator ifNil:[false]! !

!PluggableMenuItemSpec methodsFor: 'accessing' stamp: 'ar 2/28/2006 17:22'!
separator: aBool
	"Indicate whether the receiver should be followed by a separator"
	separator := aBool.! !

!PluggableMenuItemSpec methodsFor: 'accessing' stamp: 'ar 2/28/2006 17:22'!
subMenu
	"Answer the receiver's subMenu"
	^subMenu! !

!PluggableMenuItemSpec methodsFor: 'accessing' stamp: 'ar 2/28/2006 17:22'!
subMenu: aMenuSpec
	"Answer the receiver's subMenu"
	subMenu := aMenuSpec! !

ToolBuilderSpec subclass: #PluggableMenuSpec
	instanceVariableNames: 'label model items'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ToolBuilder-Kernel'!

!PluggableMenuSpec class methodsFor: 'as yet unclassified' stamp: 'cwp 6/9/2005 00:22'!
withModel: aModel
	^ self new model: aModel! !

!PluggableMenuSpec methodsFor: 'construction' stamp: 'ar 2/28/2006 17:26'!
add: aString action: aMessageSend
	| item |
	item := self addMenuItem.
	item label: aString.
	item action: aMessageSend.
	^item! !

!PluggableMenuSpec methodsFor: 'construction' stamp: 'ar 2/28/2006 17:25'!
add: aString target: anObject selector: aSelector argumentList: anArray
	^self add: aString action: (MessageSend 
				receiver: anObject 
				selector: aSelector
				arguments: anArray).! !

!PluggableMenuSpec methodsFor: 'construction' stamp: 'ar 2/28/2006 17:27'!
addMenuItem
	| item |
	item := self newMenuItem.
	self items add: item.
	^item! !

!PluggableMenuSpec methodsFor: 'construction' stamp: 'ar 2/28/2006 17:25'!
addSeparator
	self items isEmpty ifTrue:[^nil].
	self items last separator: true.! !

!PluggableMenuSpec methodsFor: 'construction' stamp: 'ar 6/21/2005 10:45'!
buildWith: builder
	^ builder buildPluggableMenu: self! !

!PluggableMenuSpec methodsFor: 'accessing' stamp: 'ar 2/28/2006 17:27'!
items
	^ items ifNil: [items := OrderedCollection new]! !

!PluggableMenuSpec methodsFor: 'accessing' stamp: 'ar 2/28/2006 17:12'!
label
	^label! !

!PluggableMenuSpec methodsFor: 'accessing' stamp: 'ar 2/28/2006 17:12'!
label: aString
	label := aString.! !

!PluggableMenuSpec methodsFor: 'accessing' stamp: 'cwp 6/8/2005 23:36'!
model
	^ model! !

!PluggableMenuSpec methodsFor: 'accessing' stamp: 'cwp 6/8/2005 23:36'!
model: anObject 
	model := anObject! !

!PluggableMenuSpec methodsFor: 'construction' stamp: 'ar 2/28/2006 17:27'!
newMenuItem
	^PluggableMenuItemSpec new! !

ToolBuilderSpec subclass: #PluggableWidgetSpec
	instanceVariableNames: 'model frame'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ToolBuilder-Kernel'!

!PluggableWidgetSpec commentStamp: 'ar 2/9/2005 18:40' prior: 0!
The abstract superclass for all widgets.

Instance variables:
	model	<Object>	The object the various requests should be directed to.
	frame	<Rectangle> The associated layout frame for this object (if any).
!

PluggableWidgetSpec subclass: #PluggableButtonSpec
	instanceVariableNames: 'action label state enabled color help'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ToolBuilder-Kernel'!

!PluggableButtonSpec commentStamp: 'ar 2/11/2005 21:57' prior: 0!
A button, both for firing as well as used in radio-button style (e.g., carrying a selection).

Instance variables:
	action	<Symbol>	The action to perform when the button is fired.
	label	<Symbol|String>	The selector for retrieving the button's label or label directly.
	state	<Symbol>	The selector for retrieving the button's selection state.
	enabled	<Symbo>		The selector for retrieving the button's enabled state.
	color	<Symbo>		The selector for retrieving the button color.
	help	<String>		The balloon help for the button.!

PluggableButtonSpec subclass: #PluggableActionButtonSpec
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ToolBuilder-Kernel'!

!PluggableActionButtonSpec commentStamp: 'ar 2/12/2005 23:12' prior: 0!
PluggableActionButtonSpec is intentded as a HINT for the builder that this widget will be used as push (action) button. Unless explicitly supported it will be automatically substituted by PluggableButton.!

!PluggableActionButtonSpec methodsFor: 'building' stamp: 'ar 2/12/2005 18:16'!
buildWith: builder
	^builder buildPluggableActionButton: self! !

!PluggableButtonSpec methodsFor: 'accessing' stamp: 'ar 2/9/2005 18:20'!
action
	"Answer the action to be performed by the receiver"
	^action! !

!PluggableButtonSpec methodsFor: 'accessing' stamp: 'ar 2/9/2005 18:20'!
action: aSymbol
	"Indicate the action to be performed by the receiver"
	action := aSymbol! !

!PluggableButtonSpec methodsFor: 'building' stamp: 'ar 2/12/2005 18:16'!
buildWith: builder
	^builder buildPluggableButton: self! !

!PluggableButtonSpec methodsFor: 'accessing' stamp: 'ar 2/11/2005 21:50'!
color
	"Answer the selector for retrieving the button's color"
	^color! !

!PluggableButtonSpec methodsFor: 'accessing' stamp: 'ar 2/11/2005 21:50'!
color: aSymbol
	"Indicate the selector for retrieving the button's color"
	color := aSymbol! !

!PluggableButtonSpec methodsFor: 'accessing' stamp: 'ar 6/21/2005 10:41'!
enabled
	"Answer the selector for retrieving the button's enablement"
	^enabled ifNil:[true]! !

!PluggableButtonSpec methodsFor: 'accessing' stamp: 'ar 2/11/2005 14:39'!
enabled: aSymbol
	"Indicate the selector for retrieving the button's enablement"
	enabled := aSymbol! !

!PluggableButtonSpec methodsFor: 'accessing' stamp: 'ar 2/10/2005 21:14'!
help
	"Answer the help text for this button"
	^help! !

!PluggableButtonSpec methodsFor: 'accessing' stamp: 'ar 2/10/2005 21:14'!
help: aString
	"Indicate the help text for this button"
	help := aString.! !

!PluggableButtonSpec methodsFor: 'accessing' stamp: 'ar 2/9/2005 18:18'!
label
	"Answer the label (or the selector for retrieving the label)"
	^label! !

!PluggableButtonSpec methodsFor: 'accessing' stamp: 'ar 2/9/2005 19:44'!
label: aSymbol
	"Indicate the selector for retrieving the label"
	label := aSymbol.! !

!PluggableButtonSpec methodsFor: 'accessing' stamp: 'ar 2/9/2005 18:19'!
state
	"Answer the selector for retrieving the button's state"
	^state! !

!PluggableButtonSpec methodsFor: 'accessing' stamp: 'ar 2/9/2005 19:44'!
state: aSymbol
	"Indicate the selector for retrieving the button's state"
	state := aSymbol.! !

PluggableButtonSpec subclass: #PluggableCheckBoxSpec
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ToolBuilder-Kernel'!

!PluggableCheckBoxSpec commentStamp: 'ar 2/12/2005 23:13' prior: 0!
PluggableCheckBox is intended as a HINT for the builder that this widget will be used as check box. Unless explicitly supported it will be automatically substituted by PluggableButton.!

!PluggableCheckBoxSpec methodsFor: 'building' stamp: 'ar 2/12/2005 18:16'!
buildWith: builder
	^builder buildPluggableCheckBox: self! !

PluggableButtonSpec subclass: #PluggableRadioButtonSpec
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ToolBuilder-Kernel'!

!PluggableRadioButtonSpec commentStamp: 'ar 2/12/2005 23:14' prior: 0!
PluggableRadioButton is intended as a HINT for the builder that this widget will be used as radio button. Unless explicitly supported it will be automatically substituted by PluggableButton.!

!PluggableRadioButtonSpec methodsFor: 'building' stamp: 'ar 2/12/2005 18:16'!
buildWith: builder
	^builder buildPluggableRadioButton: self! !

PluggableWidgetSpec subclass: #PluggableCompositeSpec
	instanceVariableNames: 'children layout'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ToolBuilder-Kernel'!

!PluggableCompositeSpec commentStamp: 'ar 2/11/2005 21:58' prior: 0!
A composite user interface element.

Instance variables:
	children	<Symbol|Collection>	Symbol to retrieve children or children directly
	layout	<Symbol> The layout for this composite.
!

!PluggableCompositeSpec methodsFor: 'accessing' stamp: 'ar 2/9/2005 19:19'!
children
	"Answer the selector to retrieve this panel's children"
	^children! !

!PluggableCompositeSpec methodsFor: 'accessing' stamp: 'ar 2/9/2005 19:19'!
children: aSymbol
	"Indicate the selector to retrieve this panel's children"
	children := aSymbol! !

!PluggableCompositeSpec methodsFor: 'accessing' stamp: 'ar 2/9/2005 18:33'!
layout
	"Answer the symbol indicating the layout of the composite:
		#proportional (default): Use frames as appropriate.
		#horizontal: Arrange the elements horizontally
		#vertical: Arrange the elements vertically.
	"
	^layout ifNil:[#proportional]! !

!PluggableCompositeSpec methodsFor: 'accessing' stamp: 'ar 2/9/2005 18:17'!
layout: aSymbol
	"Answer the symbol indicating the layout of the composite:
		#proportional (default): Use frames as appropriate.
		#horizontal: Arrange the elements horizontally
		#vertical: Arrange the elements vertically.
	"
	layout := aSymbol! !

PluggableCompositeSpec subclass: #PluggablePanelSpec
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ToolBuilder-Kernel'!

!PluggablePanelSpec commentStamp: 'ar 2/11/2005 15:01' prior: 0!
A panel with a (possibly changing) set of child elements. Expects to see change/update notifications when the childrens change.!

!PluggablePanelSpec methodsFor: 'building' stamp: 'ar 2/12/2005 18:16'!
buildWith: builder
	^builder buildPluggablePanel: self.! !

PluggableCompositeSpec subclass: #PluggableWindowSpec
	instanceVariableNames: 'label extent closeAction'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ToolBuilder-Kernel'!

!PluggableWindowSpec commentStamp: '<historical>' prior: 0!
A common window. Expects to see change/update notifications when the label should change.

Instance variables:
	label	<String|Symbol> The selector under which to retrieve the label or the label directly
	extent	<Point>	The (initial) extent of the window.
	closeAction		<Symbol>	The action to perform when the window is closed.!

!PluggableWindowSpec methodsFor: 'building' stamp: 'ar 2/12/2005 18:16'!
buildWith: builder
	^builder buildPluggableWindow: self.! !

!PluggableWindowSpec methodsFor: 'accessing' stamp: 'ar 9/17/2005 21:00'!
closeAction
	"Answer the receiver's closeAction"
	^closeAction! !

!PluggableWindowSpec methodsFor: 'accessing' stamp: 'ar 9/17/2005 21:00'!
closeAction: aSymbol
	"Answer the receiver's closeAction"
	closeAction := aSymbol.! !

!PluggableWindowSpec methodsFor: 'accessing' stamp: 'ar 2/9/2005 18:30'!
extent
	"Answer the window's (initial) extent"
	^extent! !

!PluggableWindowSpec methodsFor: 'accessing' stamp: 'ar 2/9/2005 18:30'!
extent: aPoint
	"Indicate the window's (initial) extent"
	extent := aPoint! !

!PluggableWindowSpec methodsFor: 'accessing' stamp: 'ar 2/9/2005 18:29'!
label
	"Answer the selector for retrieving the window's label"
	^label! !

!PluggableWindowSpec methodsFor: 'accessing' stamp: 'ar 2/9/2005 18:30'!
label: aString
	"Indicate the selector for retrieving the window's label"
	label := aString! !

PluggableWidgetSpec subclass: #PluggableListSpec
	instanceVariableNames: 'list getIndex setIndex getSelected setSelected menu keyPress autoDeselect dragItem dropItem dropAccept'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ToolBuilder-Kernel'!

!PluggableListSpec commentStamp: 'ar 7/15/2005 11:54' prior: 0!
A single selection list element.

Instance variables:
	list		<Symbol>	The selector to retrieve the list elements.
	getIndex	<Symbol>	The selector to retrieve the list selection index.
	setIndex	<Symbol>	The selector to set the list selection index.
	getSelected	<Symbol>	The selector to retrieve the list selection.
	setSelected	<Symbol>	The selector to set the list selection.
	menu	<Symbol>	The selector to offer (to retrieve?) the context menu.
	keyPress <Symbol>	The selector to invoke for handling keyboard shortcuts.
	autoDeselect	<Boolean>	Whether the list should allow automatic deselection or not.
	dragItem	<Symbol>	Selector to initiate a drag action on an item
	dropItem	<Symbol>	Selector to initiate a drop action of an item
	dropAccept	<Symbol>	Selector to determine whether a drop would be accepted!

!PluggableListSpec methodsFor: 'accessing' stamp: 'ar 2/12/2005 16:42'!
autoDeselect
	"Answer whether this tree can be automatically deselected"
	^autoDeselect ifNil:[true]! !

!PluggableListSpec methodsFor: 'accessing' stamp: 'ar 2/12/2005 16:41'!
autoDeselect: aBool
	"Indicate whether this tree can be automatically deselected"
	autoDeselect := aBool! !

!PluggableListSpec methodsFor: 'building' stamp: 'ar 2/12/2005 18:16'!
buildWith: builder
	^builder buildPluggableList: self! !

!PluggableListSpec methodsFor: 'accessing' stamp: 'ar 7/15/2005 11:07'!
dragItem
	"Answer the selector for dragging an item"
	^dragItem! !

!PluggableListSpec methodsFor: 'accessing' stamp: 'ar 7/15/2005 11:07'!
dragItem: aSymbol
	"Set the selector for dragging an item"
	dragItem := aSymbol! !

!PluggableListSpec methodsFor: 'accessing' stamp: 'ar 7/15/2005 11:54'!
dropAccept
	"Answer the selector to determine whether a drop would be accepted"
	^dropAccept! !

!PluggableListSpec methodsFor: 'accessing' stamp: 'ar 7/15/2005 11:55'!
dropAccept: aSymbol
	"Answer the selector to determine whether a drop would be accepted"
	dropAccept := aSymbol.! !

!PluggableListSpec methodsFor: 'accessing' stamp: 'ar 7/15/2005 11:07'!
dropItem
	"Answer the selector for dropping an item"
	^dropItem! !

!PluggableListSpec methodsFor: 'accessing' stamp: 'ar 7/15/2005 11:07'!
dropItem: aSymbol
	"Set the selector for dropping an item"
	dropItem := aSymbol! !

!PluggableListSpec methodsFor: 'accessing' stamp: 'ar 2/9/2005 18:21'!
getIndex
	"Answer the selector for retrieving the list's selection index"
	^getIndex! !

!PluggableListSpec methodsFor: 'accessing' stamp: 'ar 2/9/2005 18:21'!
getIndex: aSymbol
	"Indicate the selector for retrieving the list's selection index"
	getIndex := aSymbol! !

!PluggableListSpec methodsFor: 'accessing' stamp: 'ar 2/10/2005 22:33'!
getSelected
	"Answer the selector for retrieving the list selection"
	^getSelected! !

!PluggableListSpec methodsFor: 'accessing' stamp: 'ar 2/10/2005 22:33'!
getSelected: aSymbol
	"Indicate the selector for retrieving the list selection"
	getSelected := aSymbol! !

!PluggableListSpec methodsFor: 'accessing' stamp: 'ar 2/9/2005 18:23'!
keyPress
	"Answer the selector for invoking the list's keyPress handler"
	^keyPress! !

!PluggableListSpec methodsFor: 'accessing' stamp: 'ar 2/9/2005 18:23'!
keyPress: aSymbol
	"Indicate the selector for invoking the list's keyPress handler"
	keyPress := aSymbol! !

!PluggableListSpec methodsFor: 'accessing' stamp: 'ar 2/9/2005 18:20'!
list
	"Answer the selector for retrieving the list contents"
	^list! !

!PluggableListSpec methodsFor: 'accessing' stamp: 'ar 2/9/2005 19:24'!
list: aSymbol
	"Indicate the selector for retrieving the list contents"
	list := aSymbol.! !

!PluggableListSpec methodsFor: 'accessing' stamp: 'ar 2/9/2005 18:22'!
menu
	"Answer the selector for retrieving the list's menu"
	^menu! !

!PluggableListSpec methodsFor: 'accessing' stamp: 'ar 2/9/2005 18:22'!
menu: aSymbol
	"Indicate the selector for retrieving the list's menu"
	menu := aSymbol! !

!PluggableListSpec methodsFor: 'accessing' stamp: 'ar 2/9/2005 18:21'!
setIndex
	"Answer the selector for setting the list's selection index"
	^setIndex! !

!PluggableListSpec methodsFor: 'accessing' stamp: 'ar 2/9/2005 18:21'!
setIndex: aSymbol
	"Answer the selector for setting the list's selection index"
	setIndex := aSymbol! !

!PluggableListSpec methodsFor: 'accessing' stamp: 'ar 2/10/2005 22:34'!
setSelected
	"Answer the selector for setting the list selection"
	^setSelected! !

!PluggableListSpec methodsFor: 'accessing' stamp: 'ar 2/10/2005 22:33'!
setSelected: aSymbol
	"Indicate the selector for setting the list selection"
	setSelected := aSymbol! !

PluggableListSpec subclass: #PluggableMultiSelectionListSpec
	instanceVariableNames: 'getSelectionList setSelectionList'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ToolBuilder-Kernel'!

!PluggableMultiSelectionListSpec commentStamp: 'ar 2/12/2005 13:31' prior: 0!
PluggableMultiSelectionListSpec specifies a list with multiple selection behavior.

Instance variables:
	getSelectionList	<Symbol>	The message to retrieve the multiple selections.
	setSelectionList	<Symbol>	The message to indicate multiple selections.!

!PluggableMultiSelectionListSpec methodsFor: 'building' stamp: 'ar 2/12/2005 18:16'!
buildWith: builder
	^builder buildPluggableMultiSelectionList: self! !

!PluggableMultiSelectionListSpec methodsFor: 'accessing' stamp: 'ar 2/12/2005 13:32'!
getSelectionList
	"Answer the message to retrieve the multiple selections"
	^getSelectionList! !

!PluggableMultiSelectionListSpec methodsFor: 'accessing' stamp: 'ar 2/12/2005 13:32'!
getSelectionList: aSymbol
	"Indicate the message to retrieve the multiple selections"
	getSelectionList := aSymbol! !

!PluggableMultiSelectionListSpec methodsFor: 'accessing' stamp: 'ar 2/12/2005 13:32'!
setSelectionList
	"Answer the message to indicate multiple selections"
	^setSelectionList! !

!PluggableMultiSelectionListSpec methodsFor: 'accessing' stamp: 'ar 2/12/2005 13:32'!
setSelectionList: aSymbol
	"Indicate the message to indicate multiple selections"
	setSelectionList := aSymbol! !

PluggableWidgetSpec subclass: #PluggableTextSpec
	instanceVariableNames: 'getText setText selection menu color'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ToolBuilder-Kernel'!

!PluggableTextSpec commentStamp: 'ar 2/11/2005 21:58' prior: 0!
A text editor.

Instance variables:
	getText	<Symbol>	The selector to retrieve the text.
	setText	<Symbol>	The selector to set the text.
	selection <Symbol>	The selector to retrieve the text selection.
	menu	<Symbol>	The selector to offer (to retrieve?) the context menu.
	color	 <Symbol>	The selector to retrieve the background color.

!

PluggableTextSpec subclass: #PluggableInputFieldSpec
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ToolBuilder-Kernel'!

!PluggableInputFieldSpec commentStamp: 'ar 2/12/2005 23:13' prior: 0!
PluggableInputField is intended as a HINT for the builder that this widget will be used as a single line input field. Unless explicitly supported it will be automatically substituted by PluggableText.!

!PluggableInputFieldSpec methodsFor: 'building' stamp: 'ar 2/12/2005 18:16'!
buildWith: builder
	^builder buildPluggableInputField: self! !

!PluggableTextSpec methodsFor: 'building' stamp: 'ar 2/12/2005 18:16'!
buildWith: builder
	^builder buildPluggableText: self! !

!PluggableTextSpec methodsFor: 'accessing' stamp: 'ar 2/11/2005 21:51'!
color
	"Answer the selector for retrieving the background color"
	^color! !

!PluggableTextSpec methodsFor: 'accessing' stamp: 'ar 2/11/2005 21:51'!
color: aSymbol
	"Indicate the selector for retrieving the background color"
	color := aSymbol.! !

!PluggableTextSpec methodsFor: 'accessing' stamp: 'ar 2/9/2005 18:23'!
getText
	"Answer the selector for retrieving the text"
	^getText! !

!PluggableTextSpec methodsFor: 'accessing' stamp: 'ar 2/9/2005 18:23'!
getText: aSymbol
	"Answer the selector for retrieving the text"
	getText := aSymbol! !

!PluggableTextSpec methodsFor: 'accessing' stamp: 'ar 2/9/2005 18:25'!
menu
	"Answer the selector for retrieving the text's menu"
	^menu! !

!PluggableTextSpec methodsFor: 'accessing' stamp: 'ar 2/9/2005 18:26'!
menu: aSymbol
	"Indicate the selector for retrieving the text's menu"
	menu := aSymbol! !

!PluggableTextSpec methodsFor: 'accessing' stamp: 'ar 2/9/2005 18:25'!
selection
	"Answer the selector for retrieving the text selection"
	^selection! !

!PluggableTextSpec methodsFor: 'accessing' stamp: 'ar 2/9/2005 18:25'!
selection: aSymbol
	"Indicate the selector for retrieving the text selection"
	selection := aSymbol! !

!PluggableTextSpec methodsFor: 'accessing' stamp: 'ar 2/9/2005 18:24'!
setText
	"Answer the selector for setting the text"
	^setText! !

!PluggableTextSpec methodsFor: 'accessing' stamp: 'ar 2/9/2005 18:24'!
setText: aSymbol
	"Answer the selector for setting the text"
	setText := aSymbol! !

PluggableWidgetSpec subclass: #PluggableTreeSpec
	instanceVariableNames: 'roots getSelectedPath setSelected getChildren hasChildren label icon help menu keyPress wantsDrop dropItem dropAccept autoDeselect'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ToolBuilder-Kernel'!

!PluggableTreeSpec commentStamp: 'ar 2/12/2005 16:40' prior: 0!
A pluggable tree widget. PluggableTrees are slightly different from lists in such that they ALWAYS store the actual objects and use the label selector to query for the label of the item. PluggableTrees also behave somewhat differently in such that they do not have a "getSelected" message but only a getSelectedPath message. The difference is that getSelectedPath is used to indicate by the model that the tree should select the appropriate path. This allows disambiguation of items. Because of this, implementations of PluggableTrees must always set their internal selection directly, e.g., rather than sending the model a setSelected message and wait for an update of the #getSelected the implementation must set the selection before sending the #setSelected message. If a client doesn't want this, it can always just signal a change of getSelectedPath to revert to whatever is needed.

Instance variables:
	roots 	<Symbol>	The message to retrieve the roots of the tree.
	getSelectedPath	<Symbol> The message to retrieve the selected path in the tree.
	setSelected	<Symbol>	The message to set the selected item in the tree.
	getChildren	<Symbol>	The message to retrieve the children of an item
	hasChildren	<Symbol>	The message to query for children of an item
	label 	<Symbol>	The message to query for the label of an item.
	icon 	<Symbol>	The message to query for the icon of an item.
	help 	<Symbol>	The message to query for the help of an item.
	menu	<Symbol>	The message to query for the tree's menu
	keyPress	<Symbol>	The message to process a keystroke.
	wantsDrop	<Symbol>	The message to query whether a drop might be accepted.
	dropItem	<Symbol>	The message to drop an item.
	autoDeselect	<Boolean>	Whether the tree should allow automatic deselection or not.!

!PluggableTreeSpec methodsFor: 'accessing' stamp: 'ar 2/12/2005 17:38'!
autoDeselect
	"Answer whether this tree can be automatically deselected"
	^autoDeselect ifNil:[true]! !

!PluggableTreeSpec methodsFor: 'accessing' stamp: 'ar 2/12/2005 16:41'!
autoDeselect: aBool
	"Indicate whether this tree can be automatically deselected"
	autoDeselect := aBool! !

!PluggableTreeSpec methodsFor: 'building' stamp: 'ar 2/12/2005 18:16'!
buildWith: builder
	^builder buildPluggableTree: self! !

!PluggableTreeSpec methodsFor: 'accessing' stamp: 'ar 7/15/2005 12:09'!
dropAccept
	"Answer the selector for querying the receiver about accepting drops"
	^dropAccept! !

!PluggableTreeSpec methodsFor: 'accessing' stamp: 'ar 7/15/2005 12:09'!
dropAccept: aSymbol
	"Set the selector for querying the receiver about accepting drops"
	dropAccept := aSymbol! !

!PluggableTreeSpec methodsFor: 'accessing' stamp: 'ar 2/12/2005 00:35'!
dropItem
	"Answer the selector for invoking the tree's dragDrop handler"
	^dropItem! !

!PluggableTreeSpec methodsFor: 'accessing' stamp: 'ar 2/12/2005 00:35'!
dropItem: aSymbol
	"Indicate the selector for invoking the tree's dragDrop handler"
	dropItem := aSymbol! !

!PluggableTreeSpec methodsFor: 'accessing' stamp: 'ar 2/12/2005 00:31'!
getChildren
	"Answer the message to get the children of this tree"
	^getChildren! !

!PluggableTreeSpec methodsFor: 'accessing' stamp: 'ar 2/12/2005 00:31'!
getChildren: aSymbol
	"Indicate the message to retrieve the children of this tree"
	getChildren := aSymbol! !

!PluggableTreeSpec methodsFor: 'accessing' stamp: 'ar 2/12/2005 03:28'!
getSelectedPath
	"Answer the message to retrieve the selection of this tree"
	^getSelectedPath! !

!PluggableTreeSpec methodsFor: 'accessing' stamp: 'ar 2/12/2005 03:28'!
getSelectedPath: aSymbol
	"Indicate the message to retrieve the selection of this tree"
	getSelectedPath := aSymbol! !

!PluggableTreeSpec methodsFor: 'accessing' stamp: 'ar 2/12/2005 00:31'!
hasChildren
	"Answer the message to get the existence of children in this tree"
	^hasChildren! !

!PluggableTreeSpec methodsFor: 'accessing' stamp: 'ar 2/12/2005 00:31'!
hasChildren: aSymbol
	"Indicate the message to retrieve the existence children in this tree"
	hasChildren := aSymbol! !

!PluggableTreeSpec methodsFor: 'accessing' stamp: 'ar 2/12/2005 00:33'!
help
	"Answer the message to get the help texts of this tree"
	^help! !

!PluggableTreeSpec methodsFor: 'accessing' stamp: 'ar 2/12/2005 00:33'!
help: aSymbol
	"Indicate the message to retrieve the help texts of this tree"
	help := aSymbol! !

!PluggableTreeSpec methodsFor: 'accessing' stamp: 'ar 2/12/2005 00:32'!
icon
	"Answer the message to get the icons of this tree"
	^icon! !

!PluggableTreeSpec methodsFor: 'accessing' stamp: 'ar 2/12/2005 00:32'!
icon: aSymbol
	"Indicate the message to retrieve the icon of this tree"
	icon := aSymbol! !

!PluggableTreeSpec methodsFor: 'accessing' stamp: 'ar 2/12/2005 00:34'!
keyPress
	"Answer the selector for invoking the tree's keyPress handler"
	^keyPress! !

!PluggableTreeSpec methodsFor: 'accessing' stamp: 'ar 2/12/2005 00:34'!
keyPress: aSymbol
	"Indicate the selector for invoking the tree's keyPress handler"
	keyPress := aSymbol! !

!PluggableTreeSpec methodsFor: 'accessing' stamp: 'ar 2/12/2005 00:32'!
label
	"Answer the message to get the labels of this tree"
	^label! !

!PluggableTreeSpec methodsFor: 'accessing' stamp: 'ar 2/12/2005 00:32'!
label: aSymbol
	"Indicate the message to retrieve the labels of this tree"
	label := aSymbol! !

!PluggableTreeSpec methodsFor: 'accessing' stamp: 'ar 2/12/2005 00:33'!
menu
	"Answer the message to get the menus of this tree"
	^menu! !

!PluggableTreeSpec methodsFor: 'accessing' stamp: 'ar 2/12/2005 00:33'!
menu: aSymbol
	"Indicate the message to retrieve the menus of this tree"
	menu := aSymbol! !

!PluggableTreeSpec methodsFor: 'accessing' stamp: 'ar 2/12/2005 00:29'!
roots
	"Answer the message to retrieve the roots of this tree"
	^roots! !

!PluggableTreeSpec methodsFor: 'accessing' stamp: 'ar 2/12/2005 00:30'!
roots: aSymbol
	"Indicate the message to retrieve the roots of this tree"
	roots := aSymbol! !

!PluggableTreeSpec methodsFor: 'accessing' stamp: 'ar 2/12/2005 00:30'!
setSelected
	"Answer the message to set the selection of this tree"
	^setSelected! !

!PluggableTreeSpec methodsFor: 'accessing' stamp: 'ar 2/12/2005 00:30'!
setSelected: aSymbol
	"Indicate the message to set the selection of this tree"
	setSelected := aSymbol! !

!PluggableTreeSpec methodsFor: 'accessing' stamp: 'ar 2/12/2005 00:35'!
wantsDrop
	"Answer the selector for invoking the tree's wantsDrop handler"
	^wantsDrop! !

!PluggableTreeSpec methodsFor: 'accessing' stamp: 'ar 2/12/2005 00:35'!
wantsDrop: aSymbol
	"Indicate the selector for invoking the tree's wantsDrop handler"
	wantsDrop := aSymbol! !

!PluggableWidgetSpec methodsFor: 'accessing' stamp: 'ar 2/9/2005 18:26'!
frame
	"Answer the receiver's layout frame"
	^frame! !

!PluggableWidgetSpec methodsFor: 'accessing' stamp: 'ar 2/9/2005 18:27'!
frame: aRectangle
	"Indicate the receiver's layout frame"
	frame := aRectangle! !

!PluggableWidgetSpec methodsFor: 'accessing' stamp: 'ar 2/9/2005 18:28'!
model
	"Answer the model for which this widget should be built"
	^model! !

!PluggableWidgetSpec methodsFor: 'accessing' stamp: 'ar 2/9/2005 18:28'!
model: aModel
	"Indicate the model for which this widget should be built"
	model := aModel.! !

!ToolBuilderSpec methodsFor: 'building' stamp: 'ar 2/12/2005 18:17'!
buildWith: aBuilder
	^self subclassResponsibility! !

!ToolBuilderSpec methodsFor: 'accessing' stamp: 'cwp 4/25/2005 03:42'!
name
	^ name! !

!ToolBuilderSpec methodsFor: 'accessing' stamp: 'cwp 4/25/2005 03:40'!
name: anObject
	name := anObject! !

Object subclass: #UIManager
	instanceVariableNames: ''
	classVariableNames: 'Default'
	poolDictionaries: ''
	category: 'ToolBuilder-Kernel'!

!UIManager commentStamp: 'ar 12/27/2004 08:39' prior: 0!
UIManager is a dispatcher for various UI requests.!

!UIManager class methodsFor: 'utils' stamp: 'stephane.ducasse 7/10/2009 16:34'!
createPageTestWorkspace
	"Used to generate a workspace window for testing page up and page down stuff."
	"self createPageTestWorkspace"

	| numberOfLines maxStringLength minLineCounterSize lineCounterSize offsetSize stream headerConstant prevStart prevStrLen prevLineNumber stringLen lineNumber start log pad charIndex char |
	numberOfLines := 400.
	maxStringLength := 22.
	minLineCounterSize := 3.
	lineCounterSize := (numberOfLines log asInteger + 1) max: minLineCounterSize.
	offsetSize := 5.
	stream := ReadWriteStream on: ''.
	headerConstant := lineCounterSize + 1 + offsetSize + 1.
	prevStart := headerConstant negated.
	prevStrLen := 0.
	prevLineNumber := 0.
	numberOfLines timesRepeat: [
		stringLen := maxStringLength atRandom max: 1.
		lineNumber := prevLineNumber + 1.
		start := prevStart + prevStrLen + headerConstant + 1.
		prevStart := start.
		prevStrLen := stringLen.
		prevLineNumber := lineNumber.
		log := lineNumber log asInteger.
		pad := lineCounterSize - log - 1.
		pad timesRepeat: [stream nextPutAll: '0'].
		stream nextPutAll: lineNumber printString.
		stream space.
		log := start log asInteger.
		pad := offsetSize - log - 1.
		pad timesRepeat: [stream nextPutAll: '0'].
		stream nextPutAll: start printString.
		stream space.
		charIndex := 'a' first asInteger.
		stringLen timesRepeat: [
			char := Character value: charIndex.
			charIndex := charIndex + 1.
			stream nextPut: char].
		lineNumber = numberOfLines ifFalse: [stream cr]
		].
	self default edit: stream contents label: 'Test Data'.
! !

!UIManager class methodsFor: 'initialization' stamp: 'ar 2/11/2005 15:55'!
default
	| mgrClass |
	^Default ifNil:[
		"Note: The way the following is phrased ensures that you can always make 'more specific' managers merely by subclassing a tool builder and implementing a more specific way of reacting to #isActiveManager. For example, a BobsUIManager can subclass MorphicUIManager and (if enabled, say Preferences useBobsUI) will be considered before the parent (generic MorphicUIManager)."
		mgrClass := self allSubclasses 
			detect:[:any| any isActiveManager and:[
				any subclasses noneSatisfy:[:sub| sub isActiveManager]]] ifNone:[nil].
		mgrClass ifNotNil:[mgrClass new]
	].! !

!UIManager class methodsFor: 'initialization' stamp: 'ar 12/27/2004 09:34'!
default: aUIManager
	Default := aUIManager! !

!UIManager class methodsFor: 'initialization' stamp: 'ar 2/11/2005 15:41'!
isActiveManager
	"Answer whether I should act as the active ui manager"
	^false! !

!UIManager methodsFor: 'display' stamp: 'Pavel.Krivanek 10/28/2008 11:05'!
checkForNewDisplaySize	
	
	self subclassResponsibility ! !

!UIManager methodsFor: 'ui requests' stamp: 'ar 7/16/2005 19:35'!
chooseDirectory
	"Let the user choose a directory"
	^self chooseDirectoryFrom: FileDirectory default! !

!UIManager methodsFor: 'ui requests' stamp: 'ar 7/16/2005 19:36'!
chooseDirectory: label
	"Let the user choose a directory"
	^self chooseDirectory: label from: FileDirectory default! !

!UIManager methodsFor: 'ui requests' stamp: 'ar 7/16/2005 19:36'!
chooseDirectory: label from: dir
	"Let the user choose a directory"
	^self subclassResponsibility! !

!UIManager methodsFor: 'ui requests' stamp: 'ar 7/16/2005 19:36'!
chooseDirectoryFrom: dir
	"Let the user choose a directory"
	^self chooseDirectory: nil from: dir! !

!UIManager methodsFor: 'ui requests' stamp: 'ar 7/17/2005 00:26'!
chooseFileMatching: patterns
	"Let the user choose a file matching the given patterns"
	^self chooseFileMatching: patterns label: nil! !

!UIManager methodsFor: 'ui requests' stamp: 'ar 7/17/2005 00:26'!
chooseFileMatching: patterns label: labelString
	"Let the user choose a file matching the given patterns"
	^self subclassResponsibility! !

!UIManager methodsFor: 'ui requests' stamp: 'ar 12/27/2004 10:44'!
chooseFrom: aList
	"Choose an item from the given list. Answer the index of the selected item."
	^self chooseFrom: aList lines: #()! !

!UIManager methodsFor: 'ui requests' stamp: 'ar 12/27/2004 10:45'!
chooseFrom: aList lines: linesArray
	"Choose an item from the given list. Answer the index of the selected item."
	^self chooseFrom: aList lines: linesArray title: ''! !

!UIManager methodsFor: 'ui requests' stamp: 'ar 12/27/2004 09:37'!
chooseFrom: aList lines: linesArray title: aString
	"Choose an item from the given list. Answer the index of the selected item."
	^self subclassResponsibility! !

!UIManager methodsFor: 'ui requests' stamp: 'ar 12/27/2004 10:44'!
chooseFrom: aList title: aString
	"Choose an item from the given list. Answer the index of the selected item."
	^self chooseFrom: aList lines: #() title: aString! !

!UIManager methodsFor: 'ui requests' stamp: 'ar 7/15/2005 23:42'!
chooseFrom: labelList values: valueList
	"Choose an item from the given list. Answer the selected item."
	^self chooseFrom: labelList values: valueList lines: #()! !

!UIManager methodsFor: 'ui requests' stamp: 'ar 7/15/2005 23:43'!
chooseFrom: labelList values: valueList lines: linesArray
	"Choose an item from the given list. Answer the selected item."
	^self chooseFrom: labelList values: valueList lines: linesArray title: ''! !

!UIManager methodsFor: 'ui requests' stamp: 'ar 7/15/2005 23:43'!
chooseFrom: labelList values: valueList lines: linesArray title: aString
	"Choose an item from the given list. Answer the selected item."
	^self subclassResponsibility! !

!UIManager methodsFor: 'ui requests' stamp: 'ar 7/15/2005 23:43'!
chooseFrom: labelList values: valueList title: aString
	"Choose an item from the given list. Answer the selected item."
	^self chooseFrom: labelList values: valueList lines: #() title: aString! !

!UIManager methodsFor: 'paragraph' stamp: 'Pavel.Krivanek 10/28/2008 11:06'!
composeFormFor: aDisplayText	
	
	^ aDisplayText asParagraph asForm! !

!UIManager methodsFor: 'ui requests' stamp: 'ar 12/27/2004 08:39'!
confirm: queryString
	"Put up a yes/no menu with caption queryString. Answer true if the 
	response is yes, false if no. This is a modal question--the user must 
	respond yes or no."
	^self subclassResponsibility! !

!UIManager methodsFor: 'ui requests' stamp: 'ar 12/27/2004 09:49'!
confirm: aString orCancel: cancelBlock
	"Put up a yes/no/cancel menu with caption aString. Answer true if  
	the response is yes, false if no. If cancel is chosen, evaluate  
	cancelBlock. This is a modal question--the user must respond yes or no."
	^self subclassResponsibility! !

!UIManager methodsFor: 'ui requests' stamp: 'ar 2/28/2005 17:10'!
displayProgress: titleString at: aPoint from: minVal to: maxVal during: workBlock
	"Display titleString as a caption over a progress bar while workBlock is evaluated."
	^self subclassResponsibility! !

!UIManager methodsFor: 'ui requests' stamp: 'ar 7/16/2005 18:56'!
edit: aText
	"Open an editor on the given string/text"
	^self edit: aText label: nil! !

!UIManager methodsFor: 'ui requests' stamp: 'ar 7/16/2005 18:56'!
edit: aText label: labelString
	"Open an editor on the given string/text"
	^self edit: aText label: labelString accept: nil! !

!UIManager methodsFor: 'ui requests' stamp: 'ar 7/16/2005 18:56'!
edit: aText label: labelString accept: anAction
	"Open an editor on the given string/text"
	^self subclassResponsibility! !

!UIManager methodsFor: 'ui requests' stamp: 'Pavel.Krivanek 10/28/2008 10:45'!
fontFromUser: priorFont	
	
	self subclassResponsibility! !

!UIManager methodsFor: 'bitBlt' stamp: 'Pavel.Krivanek 10/28/2008 11:02'!
grafPort	
	
	^ Display defaultBitBltClass current! !

!UIManager methodsFor: 'ui requests' stamp: 'ar 12/27/2004 08:46'!
inform: aString
	"Display a message for the user to read and then dismiss"
	^self subclassResponsibility! !

!UIManager methodsFor: 'ui requests' stamp: 'ar 2/28/2005 20:40'!
informUser: aString during: aBlock
	"Display a message above (or below if insufficient room) the cursor 
	during execution of the given block.
		UIManager default informUser: 'Just a sec!!' during: [(Delay forSeconds: 1) wait].
	"
	^self informUserDuring:[:bar| bar value: aString. aBlock value].! !

!UIManager methodsFor: 'ui requests' stamp: 'ar 2/28/2005 17:06'!
informUserDuring: aBlock
	"Display a message above (or below if insufficient room) the cursor 
	during execution of the given block.
		UIManager default informUserDuring:[:bar|
			#(one two three) do:[:info|
				bar value: info.
				(Delay forSeconds: 1) wait]]"
	^self subclassResponsibility! !

!UIManager methodsFor: 'settings' stamp: 'Pavel.Krivanek 10/28/2008 10:49'!
interactiveParserFor: requestor	
	
	^ false! !

!UIManager methodsFor: 'ui requests' stamp: 'ar 2/28/2005 17:05'!
multiLineRequest: queryString centerAt: aPoint initialAnswer: defaultAnswer answerHeight: answerHeight
	"Create a multi-line instance of me whose question is queryString with
	the given initial answer. Invoke it centered at the given point, and
	answer the string the user accepts.  Answer nil if the user cancels.  An
	empty string returned means that the ussr cleared the editing area and
	then hit 'accept'.  Because multiple lines are invited, we ask that the user
	use the ENTER key, or (in morphic anyway) hit the 'accept' button, to 
	submit; that way, the return key can be typed to move to the next line."
	^self subclassResponsibility! !

!UIManager methodsFor: 'display' stamp: 'Pavel.Krivanek 10/28/2008 11:05'!
newDisplayDepthNoRestore: pixelSize	
	
	self subclassResponsibility ! !

!UIManager methodsFor: 'events' stamp: 'Pavel.Krivanek 10/28/2008 11:01'!
onDebug: process context: context title: title full: bool! !

!UIManager methodsFor: 'events' stamp: 'Pavel.Krivanek 10/28/2008 11:22'!
onEventSensorStartup: anEventSensor

! !

!UIManager methodsFor: 'events' stamp: 'Pavel.Krivanek 10/28/2008 11:01'!
onPrimitiveError: aString	! !

!UIManager methodsFor: 'events' stamp: 'Pavel.Krivanek 10/28/2008 11:01'!
onSnapshot	! !

!UIManager methodsFor: 'ui requests' stamp: 'ar 12/27/2004 08:41'!
request: queryString 
	"Create an instance of me whose question is queryString. Invoke it 
	centered at the cursor, and answer the string the user accepts. Answer 
	the empty string if the user cancels."
	^self request: queryString initialAnswer: ''! !

!UIManager methodsFor: 'ui requests' stamp: 'ar 12/27/2004 08:41'!
request: queryString initialAnswer: defaultAnswer 
	"Create an instance of me whose question is queryString with the given 
	initial answer. Invoke it centered at the given point, and answer the 
	string the user accepts. Answer the empty string if the user cancels."
	^self subclassResponsibility! !

!UIManager methodsFor: 'ui requests' stamp: 'ar 12/27/2004 08:47'!
requestPassword: queryString
	"Create an instance of me whose question is queryString. Invoke it centered
	at the cursor, and answer the string the user accepts. Answer the empty 
	string if the user cancels."
	^self subclassResponsibility! !

!UIManager methodsFor: 'display' stamp: 'Pavel.Krivanek 10/28/2008 11:05'!
restoreDisplay	
	
	self subclassResponsibility ! !

!UIManager methodsFor: 'display' stamp: 'Pavel.Krivanek 10/28/2008 11:05'!
restoreDisplayAfter: aBlock	
	
	self subclassResponsibility ! !
